@@ -1,12 +1,14 @@
 import shutil
 import os
 from .util import *
+import re
+
 
 def init_zood(md_dir_name):
     # 初始化 zood 文件
 
     if os.path.exists(md_dir_name):
-        print_info(f"{md_dir_name} 已存在,请删除文件夹后重试")
+        zood_info(f"{md_dir_name} 已存在,请删除文件夹后重试")
         return
     else:
         os.mkdir(md_dir_name)
@@ -21,14 +23,14 @@ def init_zood(md_dir_name):
         with open(os.path.join(md_dir_name, "README.md"), "w", encoding="utf-8") as f:
             f.write(readme)
 
-        print_info(f"已初始化 [{md_dir_name}]", "green")
+        zood_info(f"已初始化 [{md_dir_name}]", "green")
 
 
 def create_new_file(md_dir_name, dir_name, file_name):
     file_path = os.path.join(md_dir_name, dir_name, file_name + ".md")
 
     if os.path.exists(file_path):
-        print_info(f"{file_path} 已存在")
+        zood_info(f"{file_path} 已存在")
         return
 
     if not os.path.exists(os.path.join(md_dir_name, dir_name)):
@@ -40,13 +42,13 @@ def create_new_file(md_dir_name, dir_name, file_name):
         basic_info = f"\n# {file_name}\n"
         f.write(basic_info)
 
-    print_info(f"创建文件 {file_path}", color="green")
+    zood_info(f"创建文件 {file_path}", color="green")
 
 
 def init_dir_yml(md_dir_name):
     # 生成目录记录
     dir_yml = {".": [{"README": 1}]}
-    writeConfigFile(dir_yml, os.path.join(md_dir_name, "dir.yml"))
+    save_yml(dir_yml, os.path.join(md_dir_name, "dir.yml"))
 
 
 def update_dir_yml(file_name, dir_name, md_dir_name):
@@ -54,9 +56,9 @@ def update_dir_yml(file_name, dir_name, md_dir_name):
 
     current_dir = os.getcwd()
     dir_yml_path = os.path.join(current_dir, md_dir_name, "dir.yml")
-    dir_yml = read_configfile(dir_yml_path)
+    dir_yml = load_yml(dir_yml_path)
 
-    sort(dir_yml)
+    yml_sort(dir_yml)
 
     if dir_name in dir_yml.keys():
         number = list(dir_yml[dir_name][-1].values())[0] + 1
@@ -65,12 +67,10 @@ def update_dir_yml(file_name, dir_name, md_dir_name):
         dir_yml[dir_name] = []
         dir_yml[dir_name].append({file_name: 1})
 
-    writeConfigFile(dir_yml, dir_yml_path)
+    save_yml(dir_yml, dir_yml_path)
 
 
-
-
-def parse_config(config, markdown_htmls):
+def parse_config(config):
     html_dir_name = config["html_folder"]
     html_tempate_path = os.path.join(os.path.dirname(__file__), "config", "template.html")
     css_template_path = os.path.join(os.path.dirname(__file__), "config", "index.css")
@@ -79,7 +79,7 @@ def parse_config(config, markdown_htmls):
         basic_html_template = f.read()
 
     # js 部分
-    js_scope = zood_js_options(config, markdown_htmls)
+    js_scope = zood_js_options(config)
     basic_html_template = basic_html_template.replace("js-scope", js_scope)
 
     # css 部分
@@ -126,62 +126,35 @@ def get_custom_options(config, keys):
     return custom_options
 
 
-def zood_js_options(config, markdown_htmls):
+def zood_js_options(config):
     js_scope = ""
     html_dir_name = config["html_folder"]
-    md_dir_name = config["markdown_folder"]
 
     if config["options"]["enable_next_front"]:
-        js_code = insertJScode("enable_next_front", html_dir_name)
-        js_code += f"<script>addLink(<%front_url%>,<%next_url%>,<%control%>)</script>"
+        js_code = insert_js_code("enable_next_front", html_dir_name)
+        js_code += f"<script>addLink(<%front_url%>,<%next_url%>,<%control%>);</script>"
         js_scope += js_code
 
     if config["options"]["enable_change_mode"]:
-        js_code = insertJScode("enable_change_mode", html_dir_name)
-        js_code += (
-            f'<script>addChangeModeButton("../../../img/sun.png","../../../img/moon.png")</script>'
-        )
+        js_code = insert_js_code("enable_change_mode", html_dir_name)
+        js_code += f'<script>addChangeModeButton("../../../img/sun.png","../../../img/moon.png");</script>'
         js_scope += js_code
 
     if config["options"]["enable_copy_code"]:
-        js_code = insertJScode("enable_copy_code", html_dir_name)
-        js_code += f'<script>addCodeCopy("../../../img/before_copy.png","../../../img/after_copy.png")</script>'
+        js_code = insert_js_code("enable_copy_code", html_dir_name)
+        js_code += f'<script>addCodeCopy("../../../img/clipboard.svg","../../../img/clipboard-check.svg");</script>'
         js_scope += js_code
 
     if config["options"]["enable_navigator"]:
-        js_code = insertJScode("enable_navigator", html_dir_name)
+        js_code = insert_js_code("enable_navigator", html_dir_name)
         js_scope += js_code
 
-    # if config["options"]["enable_highlight"]:
-    #     # 复制prismjs
-    #     shutil.copy(
-    #         os.path.join(os.path.dirname(__file__), "config", "js", "prismjs", "prism.css"),
-    #         f"{html_dir_name}/css",
-    #     )
-    #     shutil.copy(
-    #         os.path.join(os.path.dirname(__file__), "config", "js", "prismjs", "prism.js"),
-    #         f"{html_dir_name}/js",
-    #     )
-    #     src = "../../../js/prism.js"
-    #     highlight = f'<script type="text/javascript" src="{src}"></script>'
-    #     js_scope += highlight
-
     if config["options"]["enable_picture_title"]:
-        js_code = insertJScode("enable_picture_title", html_dir_name)
+        js_code = insert_js_code("enable_picture_title", html_dir_name)
         js_scope += js_code
 
     if config["options"]["enable_picture_preview"]:
-        js_code = insertJScode("enable_picture_preview", html_dir_name)
-        js_scope += js_code
-
-    if config["options"]["enable_search"]["enable"]:
-        js_code = insertJScode("enable_search", html_dir_name)
-        all_api_text = getAllAPIText(
-            markdown_htmls,
-            config["options"]["enable_search"]["search_scope"],
-            md_dir_name,
-        )
-        js_code += f'<script>addSearchBar({all_api_text},"../../../img/search.svg","../../../img/enter.svg","Ctrl+K")</script>'
+        js_code = insert_js_code("enable_picture_preview", html_dir_name)
         js_scope += js_code
 
     if config["options"]["enable_mermaid"]:
@@ -211,12 +184,31 @@ mermaid.initialize({ startOnLoad: true });\
         """
         js_scope += js_code
 
-    js_scope += insertJScode("global_js_configuration", html_dir_name)
+    if config["options"]["enable_comment"]["enable"]:
+
+        # https://github.com/luzhixing12345/zood.git
+        # data_repo = {user_name}/{repo_name}
+        if GITHUB_REPO_URL == "":
+            zood_info("没有从 git 找到有效的 github 地址, 无法启用评论功能")
+        else:
+            data_repo = re.match(r"https://github.com/([^/]+)/([^/]+).git", GITHUB_REPO_URL).groups()
+            data_repo_id = config["options"]["enable_comment"]["repoid"]
+            data_category_id = config["options"]["enable_comment"]["categoryid"]
+            js_code = f"""
+            <script src="https://giscus.app/client.js" data-repo="{data_repo[0]}/{data_repo[1]}" 
+            data-repo-id="{data_repo_id}" data-category="Q&A" data-category-id="{data_category_id}" data-mapping="pathname" data-strict="0"
+            data-reactions-enabled="1" data-emit-metadata="0" data-input-position="bottom"
+            data-theme="preferred_color_scheme" data-lang="zh-CN" crossorigin="anonymous" async>
+            </script>
+            """
+            js_scope += js_code
+
+    js_scope += insert_js_code("global_js_configuration", html_dir_name)
 
     return js_scope
 
 
-def insertJScode(file_name: str, html_dir_name):
+def insert_js_code(file_name: str, html_dir_name):
     if file_name.startswith("enable_"):
         # 跳过enable_
         file_name = file_name[7:]
@@ -229,5 +221,3 @@ def insertJScode(file_name: str, html_dir_name):
     src = f"../../../js/{file_name}.js"
     js_code = f'<script type="text/javascript" src="{src}"></script>'
     return js_code
-
-
